@@ -6,22 +6,20 @@
  * Copyright 2002, Tim Perdue/GForge, LLC
  * Copyright 2009, Roland Mas
  *
- * This file is part of FusionForge.
+ * This file is part of FusionForge. FusionForge is free software;
+ * you can redistribute it and/or modify it under the terms of the
+ * GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the Licence, or (at your option)
+ * any later version.
  *
- * FusionForge is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published
- * by the Free Software Foundation; either version 2 of the License,
- * or (at your option) any later version.
- * 
- * FusionForge is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * FusionForge is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with FusionForge; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU General Public License along
+ * with FusionForge; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 require_once $gfcommon.'include/Error.class.php';
@@ -218,13 +216,13 @@ class ForumMessage extends Error {
 		} else {
 			$msg_id=db_insertid($result,'forum','msg_id');
 			if (!$this->fetchData($msg_id)) {
-				db_rollback();
 				$this->setError(_('ForumMessage::create() Posting Failed').' '.db_error());
+				db_rollback();
 				return false;
 			}
 			if (!$msg_id) {
-				db_rollback();
 				$this->setError(_('ForumMessage::create() Unable to get new message id'));
+				db_rollback();
 				return false;
 			} else {
 				if (!$this->sendNotice()) {
@@ -308,8 +306,8 @@ class ForumMessage extends Error {
 		}
 
 		if (!$msg_id) {
-			db_rollback();
 			$this->setError(_('ForumMessage::create() Unable to get new message id'));
+			db_rollback();
 			return false;
 		}
 
@@ -340,7 +338,7 @@ class ForumMessage extends Error {
 			$this->setError(_('Must Include A Message Body And Subject'));
 			return false;
 		}
-		if (!$this->Forum->userCanPost()) {
+		if (!forge_check_perm ('forum', $this->Forum->getID(), 'post')) {
 			$this->setPermissionDeniedError();
 			return false;
 		}
@@ -368,28 +366,11 @@ class ForumMessage extends Error {
 		db_begin();
 		
 		//now we check the moderation status of the forum and act accordingly
-		$mod_level = $this->Forum->GetModerationLevel();
-		switch ($mod_level) {
-			case 0: {
-				//no moderation
-				return $this->insertmsg($subject, $body, $thread_id, $is_followup_to,$user_id,$has_attach);
-			}
-			case 1: {
-				//moderation for anonymous & non project users
-				if ($this->Forum->userIsModLvl1()) {
-					return $this->insertmoderated($subject, $body, $thread_id, $is_followup_to,$user_id);
-				} else {
-					return $this->insertmsg($subject, $body, $thread_id, $is_followup_to,$user_id,$has_attach);
-				}
-			}
-			case 2: {
-				//moderation for anyone who can post (even project members). admins can always post...
-				if ($this->Forum->userIsModLvl2()) {
-					return $this->insertmoderated($subject, $body, $thread_id, $is_followup_to,$user_id);
-				} else {
-					return $this->insertmsg($subject, $body, $thread_id, $is_followup_to,$user_id,$has_attach);
-				}
-			}
+		if (forge_check_perm ('forum', $this->Forum->getID(), 'unmoderated_post')) {
+			//no moderation
+			return $this->insertmsg($subject, $body, $thread_id, $is_followup_to,$user_id,$has_attach);
+		} else {
+			return $this->insertmoderated($subject, $body, $thread_id, $is_followup_to,$user_id);
 		}
 	}
 
@@ -407,7 +388,7 @@ class ForumMessage extends Error {
 			$this->setError(_('ForumMessage::fetchData() Invalid MessageID').db_error());
 			return false;
 		}
-		$this->data_array =& db_fetch_array($res);
+		$this->data_array = db_fetch_array($res);
 		db_free_result($res);
 		return true;
 	}
@@ -426,7 +407,7 @@ class ForumMessage extends Error {
 			$this->setError(_('ForumMessage::fetchData() Invalid MessageID').db_error());
 			return false;
 		}
-		$this->data_array =& db_fetch_array($res);
+		$this->data_array = db_fetch_array($res);
 		db_free_result($res);
 		return true;
 	}
@@ -577,20 +558,14 @@ class ForumMessage extends Error {
 		$msg_id=$this->getID();
 		if (!$msg_id) {
 			$this->setError(_('Invalid Message ID'));
-			return 0;
+			return false;
 		}
 		
-		if (!$this->Forum->userIsAdmin()) {
+		if (!forge_check_perm ('forum_admin', $this->Forum->Group->getID())) {
 			$this->setPermissionDeniedError();
 			return false;
 		}
 		
-		/*$perm =& $this->Forum->Group->getPermission( session_get_user() );
-
-		if (!$perm || !is_object($perm) || !$perm->isForumAdmin()) {
-			$this->setPermissionDeniedError();
-			return false;
-		}*/
 		$result = db_query_params ('SELECT msg_id FROM forum 
 			WHERE is_followup_to=$1
 			AND group_forum_id=$2',
@@ -608,11 +583,11 @@ class ForumMessage extends Error {
 			AND group_forum_id=$2',
 					 array ($msg_id,
 						$this->Forum->getID())) ;
+
 		$res = db_query_params ('DELETE FROM forum_attachment where msg_id=$1',
 					array ($msg_id));
 
 		return $count;
-
 	}
 
 	/**
@@ -634,7 +609,7 @@ class ForumMessage extends Error {
 	 *	@return boolean success.
 	 */
 	function sendNotice($has_attach=false) {
-		$ids =& $this->Forum->getMonitoringIDs();
+		$ids = $this->Forum->getMonitoringIDs();
 
 		$recipients = array ();
 		foreach ($ids as $id) {
@@ -664,7 +639,7 @@ class ForumMessage extends Error {
 			}
 
 			$body = sprintf(_("\nRead and respond to this message at: \n%s"), util_make_url ('/forum/message.php?msg_id='.$this->getID()));
-			if ($GLOBALS['sys_use_mail']) {
+			if (forge_get_config('use_mail')) {
 				$body .= stripcslashes(sprintf(_('
 Or reply to this e-mail entering your response between the following markers: 
 %1$s
@@ -690,28 +665,28 @@ Or reply to this e-mail entering your response between the following markers:
 				_("You are receiving this email because you elected to monitor this forum.".
 				  "\nTo stop monitoring this forum, login to %s and visit: \n%s\n"),
 				$text,
-				$GLOBALS['sys_name'],
+				forge_get_config ('forge_name'),
 				util_make_url('/forum/monitor.php?forum_id='.$this->Forum->getID().
 					      '&group_id='.$this->Forum->Group->getID().'&stop=1')
 				);
 
-			$extra_headers = "Return-Path: <noreply@".$GLOBALS['sys_default_domain'].">\n";
-			$extra_headers .= "Errors-To: <noreply@".$GLOBALS['sys_default_domain'].">\n";
-			$extra_headers .= "Sender: <noreply@".$GLOBALS['sys_default_domain'].">\n";
+			$extra_headers = "Return-Path: <noreply@".forge_get_config('web_host').">\n";
+			$extra_headers .= "Errors-To: <noreply@".forge_get_config('web_host').">\n";
+			$extra_headers .= "Sender: <noreply@".forge_get_config('web_host').">\n";
 			$extra_headers .= "Reply-To: ".$this->Forum->getReturnEmailAddress()."\n";
 			$extra_headers .= "Precedence: Bulk\n"
-				."List-Id: ".$this->Forum->getName()." <forum".$this->Forum->getId()."@".$GLOBALS['sys_default_domain'].">\n"
+				."List-Id: ".$this->Forum->getName()." <forum".$this->Forum->getId()."@".forge_get_config('web_host').">\n"
 				."List-Help: ".util_make_url ('/forum/forum.php?id='.$this->Forum->getId())."\n"
-				."Message-Id: <forumpost".$this->getId()."@".$GLOBALS['sys_default_domain'].">";
+				."Message-Id: <forumpost".$this->getId()."@".forge_get_config('web_host').">";
 			$parentid = $this->getParentId();
 			if (!empty($parentid)) {
 				$extra_headers .= "\nIn-Reply-To: ".$this->Forum->getReturnEmailAddress()."\n"
-					."References: <forumpost".$this->getParentId()."@".$GLOBALS['sys_default_domain'].">";
+					."References: <forumpost".$this->getParentId()."@".forge_get_config('web_host').">";
 			}
 			
 			$subject="[" . $this->Forum->getUnixName() ."][".$this->getID()."] ".util_unconvert_htmlspecialchars($this->getSubject());
 
-			util_send_message($dest_email,$subject,$body,"noreply@".$GLOBALS['sys_default_domain'],'','Forum',$extra_headers);
+			util_send_message($dest_email,$subject,$body,"noreply@".forge_get_config('web_host'),'','Forum',$extra_headers);
 		}
 
 		// Switch back to the user language settings
@@ -725,7 +700,13 @@ Or reply to this e-mail entering your response between the following markers:
 	 *	@return boolean success.
 	 */
 	function sendNewModeratedMsgNotice() {
-		$ids =& $this->Forum->getForumAdminIDs();
+		$ids = array () ;
+		$engine = RBACEngine::getInstance () ;
+		$moderators = $engine->getUsersByAllowedAction ('forum', $this->Forum->getID(), 'moderate') ;
+
+		foreach ($moderators as $m) {
+			$ids[] = $m->getID () ;
+		}
 		
 		//
 		//	See if there is anyone to send messages to
@@ -750,19 +731,19 @@ Or reply to this e-mail entering your response between the following markers:
 		"\n\n______________________________________________________________________".
 		"\nYou are receiving this email because the forum you administrate has a new moderated message awaiting your approval.";
 
-		//$extra_headers = 'Reply-to: '.$this->Forum->getUnixName().'@'.$GLOBALS['sys_default_domain'];
-		$extra_headers = "Return-Path: <noreply@".$GLOBALS['sys_default_domain'].">\n";
-		$extra_headers .= "Errors-To: <noreply@".$GLOBALS['sys_default_domain'].">\n";
-		$extra_headers .= "Sender: <noreply@".$GLOBALS['sys_default_domain'].">\n";
+		//$extra_headers = 'Reply-to: '.$this->Forum->getUnixName().'@'.forge_get_config('web_host');
+		$extra_headers = "Return-Path: <noreply@".forge_get_config('web_host').">\n";
+		$extra_headers .= "Errors-To: <noreply@".forge_get_config('web_host').">\n";
+		$extra_headers .= "Sender: <noreply@".forge_get_config('web_host').">\n";
 		$extra_headers .= "Reply-To: ".$this->Forum->getReturnEmailAddress()."\n";
 		$extra_headers .= "Precedence: Bulk\n"
-			."List-Id: ".$this->Forum->getName()." <forum".$this->Forum->getId()."@".$GLOBALS['sys_default_domain'].">\n"
+			."List-Id: ".$this->Forum->getName()." <forum".$this->Forum->getId()."@".forge_get_config('web_host').">\n"
 			."List-Help: ".util_make_url('/forum/forum.php?id='.$this->Forum->getId())."\n"
-			."Message-Id: <forumpost".$this->getId()."@".$GLOBALS['sys_default_domain'].">";
+			."Message-Id: <forumpost".$this->getId()."@".forge_get_config('web_host').">";
 		$parentid = $this->getParentId();
 		if (!empty($parentid)) {
  			$extra_headers .= "\nIn-Reply-To: ".$this->Forum->getReturnEmailAddress()."\n"
-				."References: <forumpost".$this->getParentId()."@".$GLOBALS['sys_default_domain'].">";
+				."References: <forumpost".$this->getParentId()."@".forge_get_config('web_host').">";
 		}
 
 		$subject="[" . $this->Forum->getUnixName() ."][".$this->getID()."] ".util_unconvert_htmlspecialchars($this->getSubject());
@@ -772,11 +753,11 @@ Or reply to this e-mail entering your response between the following markers:
 							  db_int_array_to_any_clause ($ids))) ;
 		}
 		
-		$BCC =& implode(util_result_column_to_array($bccres),',').','.$this->Forum->getSendAllPostsTo();
+		$BCC = implode(util_result_column_to_array($bccres),',').','.$this->Forum->getSendAllPostsTo();
 		$User = user_get_object($this->getPosterID());
 		//util_send_message('',$subject,$body,$User->getEmail(),$BCC,$this->getPosterRealName(),$extra_headers);
-		util_send_message('',$subject,$body,"noreply@".$GLOBALS['sys_default_domain'],$BCC,'Forum',$extra_headers);
-//		util_handle_message(array_unique($ids),$subject,$body,$this->Forum->getSendAllPostsTo(),'','forumgateway@'.$GLOBALS[sys_default_domain]);
+		util_send_message('',$subject,$body,"noreply@".forge_get_config('web_host'),$BCC,'Forum',$extra_headers);
+//		util_handle_message(array_unique($ids),$subject,$body,$this->Forum->getSendAllPostsTo(),'','forumgateway@'.forge_get_config('web_host'));
 		return true;
 	}
 
@@ -834,7 +815,7 @@ Or reply to this e-mail entering your response between the following markers:
 	 */
 	function sendAttachNotice($attach_id) {
 		if ($attach_id) {
-			$ids =& $this->Forum->getMonitoringIDs();
+			$ids = $this->Forum->getMonitoringIDs();
 
 			//
 			//	See if there is anyone to send messages to
@@ -853,21 +834,21 @@ Or reply to this e-mail entering your response between the following markers:
 			$body .=
 			"\n\n______________________________________________________________________".
 			"\nYou are receiving this email because you elected to monitor this forum.".
-			"\nTo stop monitoring this forum, login to ".$GLOBALS['sys_name']." and visit: ".
-				"\n".util_make_url ('/forum/monitor.php?forum_id='.$this->Forum->getID() .'&group_id='.$this->Forum->Group->getID().'&stop=1');
+			"\nTo stop monitoring this forum, login to ".forge_get_config ('forge_name')." and visit: ".
+			"\n".util_make_url ('/forum/monitor.php?forum_id='.$this->Forum->getID() .'&group_id='.$this->Forum->Group->getID().'&stop=1');
 	
-			$extra_headers = "Return-Path: <noreply@".$GLOBALS['sys_default_domain'].">\n";
-			$extra_headers .= "Errors-To: <noreply@".$GLOBALS['sys_default_domain'].">\n";
-			$extra_headers .= "Sender: <noreply@".$GLOBALS['sys_default_domain'].">\n";
+			$extra_headers = "Return-Path: <noreply@".forge_get_config('web_host').">\n";
+			$extra_headers .= "Errors-To: <noreply@".forge_get_config('web_host').">\n";
+			$extra_headers .= "Sender: <noreply@".forge_get_config('web_host').">\n";
 			$extra_headers .= "Reply-To: ".$this->Forum->getReturnEmailAddress()."\n";
 			$extra_headers .= "Precedence: Bulk\n"
-				."List-Id: ".$this->Forum->getName()." <forum".$this->Forum->getId()."@".$GLOBALS['sys_default_domain'].">\n"
+				."List-Id: ".$this->Forum->getName()." <forum".$this->Forum->getId()."@".forge_get_config('web_host').">\n"
 				."List-Help: ".util_make_url('/forum/forum.php?id='.$this->Forum->getId())."\n"
-				."Message-Id: <forumpost".$this->getId()."@".$GLOBALS['sys_default_domain'].">";
+				."Message-Id: <forumpost".$this->getId()."@".forge_get_config('web_host').">";
 			$parentid = $this->getParentId();
 			if (!empty($parentid)) {
 				$extra_headers .= "\nIn-Reply-To: ".$this->Forum->getReturnEmailAddress()."\n"
-					."References: <forumpost".$this->getParentId()."@".$GLOBALS['sys_default_domain'].">";
+					."References: <forumpost".$this->getParentId()."@".forge_get_config('web_host').">";
 			}
 	
 			$subject="[" . $this->Forum->getUnixName() ."][".$this->getID()."] ".util_unconvert_htmlspecialchars($this->getSubject());
@@ -876,9 +857,9 @@ Or reply to this e-mail entering your response between the following markers:
 							   array ('A',
 								  db_int_array_to_any_clause ($ids))) ;
 			}
-			$BCC =& implode(util_result_column_to_array($bccres),',').','.$this->Forum->getSendAllPostsTo();
+			$BCC = implode(util_result_column_to_array($bccres),',').','.$this->Forum->getSendAllPostsTo();
 			$User = user_get_object($this->getPosterID());
-			util_send_message('',$subject,$body,"noreply@".$GLOBALS['sys_default_domain'],$BCC,'Forum',$extra_headers);
+			util_send_message('',$subject,$body,"noreply@".forge_get_config('web_host'),$BCC,'Forum',$extra_headers);
 			return true;
 		}
 		
