@@ -1,8 +1,9 @@
 <?php
 /** FusionForge Subversion plugin
  *
- * Copyright 2003-2009, Roland Mas
+ * Copyright 2003-2010, Roland Mas, Franck Villaume
  * Copyright 2004, GForge, LLC
+ * Copyright 2010, Alain Peyrat <aljeux@free.fr>
  *
  * This file is part of FusionForge.
  *
@@ -10,46 +11,51 @@
  * it under the terms of the GNU General Public License as published
  * by the Free Software Foundation; either version 2 of the License,
  * or (at your option) any later version.
- * 
+ *
  * FusionForge is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with FusionForge; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+forge_define_config_item ('default_server', 'scmsvn', forge_get_config ('web_host')) ;
+forge_define_config_item ('repos_path', 'scmsvn', forge_get_config('chroot').'/scmrepos/svn') ;
+forge_define_config_item ('use_ssh', 'scmsvn', false) ;
+forge_set_config_item_bool ('use_ssh', 'scmsvn') ;
+forge_define_config_item ('use_dav', 'scmsvn', true) ;
+forge_set_config_item_bool ('use_dav', 'scmsvn') ;
+forge_define_config_item ('use_ssl', 'scmsvn', true) ;
+forge_set_config_item_bool ('use_ssl', 'scmsvn') ;
+forge_define_config_item ('anonsvn_login','scmsvn', 'anonsvn');
+forge_define_config_item ('anonsvn_password','scmsvn', 'anonsvn');
+
 class SVNPlugin extends SCMPlugin {
 	function SVNPlugin () {
-		global $gfconfig;
 		$this->SCMPlugin () ;
 		$this->name = 'scmsvn';
-		$this->text = 'SVN';
+		$this->text = 'Subversion';
+		$this->svn_root_fs = '/scmrepos/svn';
+		if (!file_exists($this->svn_root_fs.'/.')) {
+			$this->svn_root_fs = forge_get_config('repos_path',
+			    $this->name);
+		}
+		$this->svn_root_dav = '/svn';
 		$this->hooks[] = 'scm_browser_page';
 		$this->hooks[] = 'scm_update_repolist' ;
 		$this->hooks[] = 'scm_generate_snapshots' ;
 		$this->hooks[] = 'scm_gather_stats' ;
 
-		require $gfconfig.'plugins/scmsvn/config.php' ;
-
-		$this->default_svn_server = $default_svn_server ;
-		$this->use_ssh = $use_ssh;
-		$this->use_dav = $use_dav;
-		$this->use_ssl = $use_ssl;
-		if (isset ($svn_root)) {
-			$this->svn_root = $svn_root;
-		} else {
-			$this->svn_root = $GLOBALS['sys_chroot'].'/scmrepos/svn' ;
-		}
+		$this->provides['svn'] = true;
 
 		$this->register () ;
 	}
-	
+
 	function getDefaultServer() {
-		return $this->default_svn_server ;
+		return forge_get_config('default_server', 'scmsvn') ;
 	}
 
 	function printShortStats ($params) {
@@ -69,23 +75,41 @@ class SVNPlugin extends SCMPlugin {
 			if (!$add_num) {
 				$add_num=0;
 			}
-			echo ' (SVN: '.sprintf(_('<strong>%1$s</strong> commits, <strong>%2$s</strong> adds'), number_format($commit_num, 0), number_format($add_num, 0)).")";
+			echo ' (Subversion: '.sprintf(_('<strong>%1$s</strong> commits, <strong>%2$s</strong> adds'), number_format($commit_num, 0), number_format($add_num, 0)).")";
 		}
 	}
-	
+
 	function getBlurb () {
-		return _('<p>Documentation for Subversion (sometimes referred to as "SVN") is available <a href="http://svnbook.red-bean.com/">here</a>.</p>') ;
+		return '<p>' . _('Documentation for Subversion (sometimes referred to as "SVN") is available <a href="http://svnbook.red-bean.com/">here</a>.') . '</p>';
+	}
+
+	function topModule ($project) {
+		// Check toplevel module presence
+		$repo = 'file://' . forge_get_config('repos_path', $this->name).'/'.$project->getUnixName().'/';
+		$res = array ();
+		$module = 'trunk';
+		if (!(exec("svn ls '$repo'", $res) && in_array($module.'/', $res)))
+		{
+			$module = '';
+		}
+
+		return '/'.$module;
 	}
 
 	function getInstructionsForAnon ($project) {
-		$b =  _('<p><b>Anonymous Subversion Access</b></p><p>This project\'s SVN repository can be checked out through anonymous access with the following command(s).</p>');
+		$b = '<h2>' . _('Anonymous Subversion Access') . '</h2>';
+		$b .= '<p>';
+		$b .= _("This project's SVN repository can be checked out through anonymous access with the following command(s).");
+		$b .= '</p>';
+
 		$b .= '<p>' ;
-		if ($this->use_ssh) {
-			$b .= '<tt>svn checkout svn://'.$project->getSCMBox().$this->svn_root.'/'.$project->getUnixName().'/trunk</tt><br />';
+		$module = $this->topModule($project);
+		if (forge_get_config('use_ssh', 'scmsvn')) {
+			$b .= '<tt>svn checkout svn://'.$project->getSCMBox().$this->svn_root_fs.'/'.$project->getUnixName().$module.'</tt><br />';
 		}
-		if ($this->use_dav) {
-			$url = 'http://' . $project->getSCMBox(). $this->svn_root .'/'. $project->getUnixName() .'/trunk';
-			$b .= '<tt>svn checkout <a href="'.$url.'">'.$url.'</a> '.$project->getUnixName().'-trunk</tt>';
+		if (forge_get_config('use_dav', 'scmsvn')) {
+			$b .= '<tt>svn checkout --username '.forge_get_config('anonsvn_login', 'scmsvn').' http'.((forge_get_config('use_ssl', 'scmsvn')) ? 's' : '').'://' . $project->getSCMBox(). $this->svn_root_dav .'/'. $project->getUnixName() .$module.'</tt><br/><br/>';
+			$b .= _('The password is ').forge_get_config('anonsvn_password', 'scmsvn').'<br/>';
 		}
 		$b .= '</p>';
 		return $b ;
@@ -93,27 +117,48 @@ class SVNPlugin extends SCMPlugin {
 
 	function getInstructionsForRW ($project) {
 		$b = '' ;
+
+		$module = $this->topModule($project);
+
 		if (session_loggedin()) {
 			$u =& user_get_object(user_getid()) ;
 			$d = $u->getUnixName() ;
-			if ($this->use_ssh) {
-				$b .= _('<p><b>Developer Subversion Access via SSH</b></p><p>Only project developers can access the SVN tree via this method. SSH must be installed on your client machine. Enter your site password when prompted.</p>');
-				$b .= '<p><tt>svn checkout svn+ssh://'.$d.'@' . $project->getSCMBox() . $this->svn_root .'/'. $project->getUnixName().'/trunk</tt></p>' ;
+			if (forge_get_config('use_ssh', 'scmsvn')) {
+				$b .= '<h2>';
+				$b .= _('Developer Subversion Access via SSH');
+				$b .= '</h2>';
+				$b .= '<p>';
+				$b .= _('Only project developers can access the SVN tree via this method. SSH must be installed on your client machine. Enter your site password when prompted.');
+				$b .= '</p>';
+				$b .= '<p><tt>svn checkout svn+ssh://'.$d.'@' . $project->getSCMBox() . $this->svn_root_fs .'/'. $project->getUnixName().$module.'</tt></p>' ;
 			}
-			if ($this->use_dav) {
-				$b .= _('<p><b>Developer Subversion Access via DAV</b></p><p>Only project developers can access the SVN tree via this method. Enter your site password when prompted.</p>');
-				$url = 'http'.(($this->use_ssl) ? 's' : '').'://'. $project->getSCMBox() . $this->svn_root .'/'.$project->getUnixName().'/trunk' ;
-				$b .= '<p><tt>svn checkout --username '.$d.' <a href="'.$url.'">'.$url.'</a> '.$project->getUnixName().'-trunk</tt></p>' ;
+			if (forge_get_config('use_dav', 'scmsvn')) {
+				$b .= '<h2>';
+				$b .= _('Developer Subversion Access via DAV');
+				$b .= '</h2>';
+				$b .= '<p>';
+				$b .= _('Only project developers can access the SVN tree via this method. Enter your site password when prompted.');
+				$b .= '</p>';
+				$b .= '<p><tt>svn checkout --username '.$d.' http'.((forge_get_config('use_ssl', 'scmsvn')) ? 's' : '').'://'. $project->getSCMBox() . $this->svn_root_dav .'/'.$project->getUnixName().$module.'</tt></p>' ;
 			}
 		} else {
-			if ($this->use_ssh) {
-				$b .= _('<p><b>Developer Subversion Access via SSH</b></p><p>Only project developers can access the SVN tree via this method. SSH must be installed on your client machine. Substitute <i>developername</i> with the proper values. Enter your site password when prompted.</p>');
-				$b .= '<p><tt>svn checkout svn+ssh://<i>'._('developername').'</i>@' . $project->getSCMBox() . $this->svn_root .'/'. $project->getUnixName().'/trunk</tt></p>' ;
+			if (forge_get_config('use_ssh', 'scmsvn')) {
+				$b .= '<h2>';
+				$b .= _('Developer Subversion Access via SSH');
+				$b .= '</h2>';
+				$b .= '<p>';
+				$b .= _('Only project developers can access the SVN tree via this method. SSH must be installed on your client machine. Substitute <i>developername</i> with the proper values. Enter your site password when prompted.');
+				$b .= '</p>';
+				$b .= '<p><tt>svn checkout svn+ssh://<i>'._('developername').'</i>@' . $project->getSCMBox() . $this->svn_root_fs .'/'. $project->getUnixName().$module.'</tt></p>' ;
 			}
-			if ($this->use_dav) {
-				$b .= _('<p><b>Developer Subversion Access via DAV</b></p><p>Only project developers can access the SVN tree via this method. Substitute <i>developername</i> with the proper values. Enter your site password when prompted.</p>');
-				$url = 'http'.(($this->use_ssl) ? 's' : '').'://'. $project->getSCMBox() . $this->svn_root .'/'.$project->getUnixName().'/trunk' ;
-				$b .= '<p><tt>svn checkout --username <i>'._('developername').'</i> <a href="'.$url.'">'.$url.'</a> '.$project->getUnixName().'-trunk</tt></p>' ;
+			if (forge_get_config('use_dav', 'scmsvn')) {
+				$b .= '<h2>';
+				$b .= _('Developer Subversion Access via DAV');
+				$b .= '</h2>';
+				$b .= '<p>';
+				$b .= _('Only project developers can access the SVN tree via this method. Substitute <i>developername</i> with the proper values. Enter your site password when prompted.');
+				$b .= '</p>';
+				$b .= '<p><tt>svn checkout --username <i>'._('developername').'</i> http'.((forge_get_config('use_ssl', 'scmsvn')) ? 's' : '').'://'. $project->getSCMBox() . $this->svn_root_dav .'/'.$project->getUnixName().$module.'</tt></p>' ;
 			}
 		}
 		return $b ;
@@ -126,7 +171,9 @@ class SVNPlugin extends SCMPlugin {
 	function getBrowserLinkBlock ($project) {
 		global $HTML ;
 		$b = $HTML->boxMiddle(_('Subversion Repository Browser'));
-		$b .= _('<p>Browsing the Subversion tree gives you a view into the current status of this project\'s code. You may also view the complete histories of any file in the repository.</p>');
+		$b .= '<p>';
+		$b .= _('Browsing the Subversion tree gives you a view into the current status of this project\'s code. You may also view the complete histories of any file in the repository.');
+		$b .= '</p>';
 		$b .= '<p>[' ;
 		$b .= util_make_link ("/scm/browser.php?group_id=".$project->getID(),
 				      _('Browse Subversion Repository')
@@ -177,16 +224,14 @@ class SVNPlugin extends SCMPlugin {
 	}
 
 	function printBrowserPage ($params) {
-		global $HTML;
-
 		$project = $this->checkParams ($params) ;
 		if (!$project) {
 			return false ;
 		}
-		
+
 		if ($project->usesPlugin ($this->name)) {
 			if ($this->browserDisplayable ($project)) {
-				print '<iframe src="'.util_make_url ("/scm/viewvc.php/?root=".$project->getUnixName()).'" frameborder="no" width=100% height=700></iframe>' ;
+				session_redirect("/scm/viewvc.php/?root=".$project->getUnixName());
 			}
 		}
 	}
@@ -196,19 +241,21 @@ class SVNPlugin extends SCMPlugin {
 		if (!$project) {
 			return false ;
 		}
-		
+
 		if (! $project->usesPlugin ($this->name)) {
 			return false;
 		}
 
-		$repo = $this->svn_root . '/' . $project->getUnixName() ;
+		$repo = forge_get_config('repos_path', 'scmsvn') . '/' . $project->getUnixName() ;
 
 		if (!is_dir ($repo) || !is_file ("$repo/format")) {
 			system ("svnadmin create $repo") ;
-			system ("svn mkdir -m'Init' file:///$repo/trunk file:///$repo/tags file:///$repo/branches") ;
+			system ("svn mkdir -m'Init' file:///$repo/trunk file:///$repo/tags file:///$repo/branches >/dev/null") ;
 		}
 
-		if ($this->use_ssh) {
+		$this->installOrUpdateCmds($project, $project->getUnixName(), $repo);
+
+		if (forge_get_config('use_ssh', 'scmsvn')) {
 			$unix_group = 'scm_' . $project->getUnixName() ;
 			system ("find $repo -type d | xargs chmod g+s") ;
 			system ("chgrp -R $unix_group $repo") ;
@@ -218,19 +265,18 @@ class SVNPlugin extends SCMPlugin {
 				system ("chmod -R g+wX,o-rwx $repo") ;
 			}
 		} else {
-			$unix_user = $GLOBALS['sys_apache_user'];
-			$unix_group = $GLOBALS['sys_apache_group'];
+			$unix_user = forge_get_config('apache_user');
+			$unix_group = forge_get_config('apache_group');
 			system ("chown -R $unix_user:$unix_group $repo") ;
 			system ("chmod -R g-rwx,o-rwx $repo") ;
 		}
 	}
 
 	function updateRepositoryList ($params) {
-		global $sys_var_path ;
 		$groups = $this->getGroups () ;
 
 		// Update WebDAV stuff
-		if (!$this->use_dav) {
+		if (!forge_get_config('use_dav', 'scmsvn')) {
 			return true ;
 		}
 
@@ -242,21 +288,30 @@ class SVNPlugin extends SCMPlugin {
 			if ( !$project->isActive()) {
 				continue;
 			}
+			if ( !$project->usesSCM()) {
+				continue;
+			}
+			$access_data .= '[' . $project->getUnixName () . ":/]\n" ;
+			
 			$users = $project->getMembers () ;
 			foreach ($users as $user) {
-				$perm = $project->getPermission ($user) ;
-				if ($perm->isMember ('scm', 0)) {
+				if (forge_check_perm_for_user ($user,
+							       'scm',
+							       $project->getID(),
+							       'write')) {
+					$access_data .= $user->getUnixName() . "= rw\n" ;
+					$svnusers[$user->getID()] = $user ;
+				} elseif (forge_check_perm_for_user ($user,
+								     'scm',
+								     $project->getID(),
+								     'read')) {
+					$access_data .= $user->getUnixName() . "= r\n" ;
 					$svnusers[$user->getID()] = $user ;
 				}
-				$access_data .= '[' . $project->getUnixName () . ":/]\n" ;
-				if ($perm->isMember ('scm', 1)) {
-					$access_data .= $user->getUnixName() . "= rw\n" ;
-				} elseif ($perm->isMember ('scm', 0)) {
-					$access_data .= $user->getUnixName() . "= r\n" ;
-				}
 			}
+
 			if ( $project->enableAnonSCM() ) {
-				$access_data .= "anonsvn= r\n" ;
+				$access_data .= forge_get_config('anonsvn_login', 'scmsvn')." = r\n" ;
 				$access_data .= "* = r\n" ;
 				
 			}
@@ -266,16 +321,16 @@ class SVNPlugin extends SCMPlugin {
 		foreach ($svnusers as $user_id => $user) {
 			$password_data .= $user->getUnixName().':'.$user->getUnixPasswd()."\n" ;
 		}
-		$password_data .= 'anonsvn:$apr1$Kfr69/..$J08mbyNpD81y42x7xlFDm.'."\n";
+		$password_data .= forge_get_config('anonsvn_login', 'scmsvn').":".htpasswd_apr1_md5(forge_get_config('anonsvn_password', 'scmsvn'))."\n";
 
-		$fname = $sys_var_path.'/svnroot-authfile' ;
+		$fname = forge_get_config('data_path').'/svnroot-authfile' ;
 		$f = fopen ($fname.'.new', 'w') ;
 		fwrite ($f, $password_data) ;
 		fclose ($f) ;
 		chmod ($fname.'.new', 0644) ;
 		rename ($fname.'.new', $fname) ;
 
-		$fname = $sys_var_path.'/svnroot-access' ;
+		$fname = forge_get_config('data_path').'/svnroot-access' ;
 		$f = fopen ($fname.'.new', 'w') ;
 		fwrite ($f, $access_data) ;
 		fclose ($f) ;
@@ -294,7 +349,7 @@ class SVNPlugin extends SCMPlugin {
 		if (!$project) {
 			return false ;
 		}
-		
+
 		if (! $project->usesPlugin ($this->name)) {
 			return false;
 		}
@@ -309,20 +364,20 @@ class SVNPlugin extends SCMPlugin {
 			$start_time = gmmktime( 0, 0, 0, $month, $day, $year);
 			$end_time = $start_time + 86400;
 
+			$adds    = 0 ;
 			$updates = 0 ;
-			$adds = 0 ;
-			$usr_adds = array () ;
+			$usr_adds    = array () ;
 			$usr_updates = array () ;
 
-			$repo = $this->svn_root . '/' . $project->getUnixName() ;
+			$repo = forge_get_config('repos_path', 'scmsvn') . '/' . $project->getUnixName() ;
 			if (!is_dir ($repo) || !is_file ("$repo/format")) {
 				echo "No repository\n" ;
 				db_rollback () ;
 				return false ;
 			}
-	
-                        $d1 = date ('Y-m-d', $start_time - 150000) ;
-                        $d2 = date ('Y-m-d', $end_time + 150000) ;
+
+			$d1 = date ('Y-m-d', $start_time - 150000) ;
+			$d2 = date ('Y-m-d', $end_time + 150000) ;
 
 			$pipe = popen ("svn log file://$repo --xml -v -q -r '".'{'.$d2.'}:{'.$d1.'}'."' 2> /dev/null", 'r' ) ;
 
@@ -346,7 +401,7 @@ class SVNPlugin extends SCMPlugin {
 				db_rollback () ;
 				return false ;
 			}
-	
+
 			$xml_parser = xml_parser_create();
 			xml_set_element_handler($xml_parser, "SVNPluginStartElement", "SVNPluginEndElement");
 			xml_set_character_data_handler($xml_parser, "SVNPluginCharData");
@@ -365,7 +420,7 @@ class SVNPlugin extends SCMPlugin {
 					break;
 				}
 			}
-			
+
 			xml_parser_free ($xml_parser);
 
 			// inserting group results in stats_cvs_groups
@@ -382,7 +437,7 @@ class SVNPlugin extends SCMPlugin {
 					return false ;
 				}
 			}
-				
+
 			// building the user list
 			$user_list = array_unique( array_merge( array_keys( $usr_adds ), array_keys( $usr_updates ) ) );
 
@@ -394,9 +449,9 @@ class SVNPlugin extends SCMPlugin {
 				} else {
 					continue;
 				}
-		
-				$uu = $usr_updates[$user] ? $usr_updates[$user] : 0 ;
-				$ua = $usr_adds[$user] ? $usr_adds[$user] : 0 ;
+
+				$uu = isset($usr_updates[$user]) ? $usr_updates[$user] : 0 ;
+				$ua = isset($usr_adds[$user]) ? $usr_adds[$user] : 0 ;
 				if ($uu > 0 || $ua > 0) {
 					if (!db_query_params ('INSERT INTO stats_cvs_user (month,day,group_id,user_id,commits,adds) VALUES ($1,$2,$3,$4,$5,$6)',
 							      array ($month_string,
@@ -416,18 +471,16 @@ class SVNPlugin extends SCMPlugin {
 	}
 
 	function generateSnapshots ($params) {
-		global $sys_scm_snapshots_path ;
-		global $sys_scm_tarballs_path ;
 
 		$project = $this->checkParams ($params) ;
 		if (!$project) {
 			return false ;
 		}
-		
+
 		$group_name = $project->getUnixName() ;
 
-		$snapshot = $sys_scm_snapshots_path.'/'.$group_name.'-scm-latest.tar.gz';
-		$tarball = $sys_scm_tarballs_path.'/'.$group_name.'-scmroot.tar.gz';
+		$snapshot = forge_get_config('scm_snapshots_path').'/'.$group_name.'-scm-latest.tar.gz';
+		$tarball = forge_get_config('scm_tarballs_path').'/'.$group_name.'-scmroot.tar.gz';
 
 		if (! $project->usesPlugin ($this->name)) {
 			return false;
@@ -443,7 +496,7 @@ class SVNPlugin extends SCMPlugin {
 			return false;
 		}
 
-		$toprepo = $this->svn_root ;
+		$toprepo = forge_get_config('repos_path', 'scmsvn') ;
 		$repo = $toprepo . '/' . $project->getUnixName() ;
 
 		if (!is_dir ($repo) || !is_file ("$repo/format")) {
@@ -466,7 +519,7 @@ class SVNPlugin extends SCMPlugin {
 		$code = 0 ;
 		system ("svn ls file://$repo/trunk > /dev/null", $code) ;
 		if ($code == 0) {
-			system ("cd $tmp ; svn checkout file://$repo/trunk $dir > /dev/null 2>&1") ;
+			system ("cd $tmp ; svn export file://$repo/trunk $dir > /dev/null 2>&1") ;
 			system ("tar czCf $tmp $tmp/snapshot.tar.gz $dir") ;
 			chmod ("$tmp/snapshot.tar.gz", 0644) ;
 			copy ("$tmp/snapshot.tar.gz", $snapshot) ;
@@ -484,7 +537,86 @@ class SVNPlugin extends SCMPlugin {
 		unlink ("$tmp/tarball.tar.gz") ;
 		system ("rm -rf $tmp") ;
 	}
-  }
+
+	function installOrUpdateCmds($project, $unix_group_name, $repos) {
+
+		$hooks = array();
+		$params = array();
+		$params['unix_group_name'] = $unix_group_name;
+		$group = group_get_object_by_name($unix_group_name);
+		$params['group_id'] = $group->getID();
+		$params['repos'] = $repos;
+		$params['hooks'] = &$hooks;
+		plugin_hook('cmd_for_post_commit_hook', $params);
+
+		foreach ($params['hooks'] as $plugin => $cmd ) {
+			if (getenv('sys_localinc')) {
+				$cmd = 'sys_localinc='.getenv(sys_localinc).' '.$cmd;
+			}
+			$contents = @file_get_contents($repos."/hooks/post-commit");
+			if ($project->usesPlugin($plugin)) {
+				if (strstr($contents, "#begin added by $plugin") === false ) {
+					$this->installCmdInHook($repos, $plugin, $cmd);
+				} else {
+					$this->updateCmdInHook($repos, $plugin, $cmd);
+				}
+			} elseif (!$project->usesPlugin($plugin) &&
+			(strstr($contents, "#begin added by $plugin") !== false )) {
+				$this->removeCmdInHook($repos, $plugin);
+			}
+		}
+	}
+
+	function installCmdInHook($repos, $name, $text) {
+
+		if (file_exists($repos.'/hooks/post-commit')) {
+			$FOut = fopen($repos.'/hooks/post-commit', "a+");
+			$Line = '';
+		} else {
+			$FOut = fopen($repos.'/hooks/post-commit', "w");
+			$Line = '#!/bin/sh'."\n"; // add this line to first line or else the script fails
+		}
+
+		if ($FOut) {
+			$Line .= "\n#begin added by $name\n$text\n#end added by $name\n";
+
+			fwrite($FOut, $Line);
+
+			system("chmod 700 $repos/hooks/post-commit");
+			fclose($FOut);
+		}
+	}
+
+	function updateCmdInHook($repos, $plugin, $text) {
+
+		$contents = @file_get_contents($repos."/hooks/post-commit");
+
+		$new = preg_replace("/(#begin added by $plugin\n)(.*)(\n#end added by $plugin)/s", '$1{COMMAND}$3', $contents);
+		$new = str_replace('{COMMAND}', $text, $new);
+
+		if ($contents !== $new) {
+			$fout = fopen($repos.'/hooks/post-commit', "w");
+			fwrite($fout, $new);
+			fclose($fout);
+		}
+	}
+
+	function removeCmdInHook($repos, $plugin) {
+
+		$contents = @file_get_contents($repos."/hooks/post-commit");
+		$new = preg_replace("/#begin added by $plugin\n.*?\n#end added by $plugin/s", '', $contents);
+
+		if ($contents !== $new) {
+			if (preg_match("/^#\!\/bin\/sh(\n+)$/s", $new)) {
+				unlink($repos.'/hooks/post-commit');
+			} else {
+				$fout = fopen($repos.'/hooks/post-commit', "w");
+				fwrite($fout, $new);
+				fclose($fout);
+			}
+		}
+	}
+}
 
 // End of class, helper functions now
 
@@ -523,12 +655,12 @@ function SVNPluginStartElement($parser, $name, $attrs) {
 			if ($attrs['ACTION'] == "M") {
 				$updates++;
 				if ($last_user) {
-					$usr_updates[$last_user]++;
+					$usr_updates[$last_user] = isset($usr_updates[$last_user]) ? ($usr_updates[$last_user]+1) : 0 ;
 				}
 			} elseif ($attrs['ACTION'] == "A") {
 				$adds++;
 				if ($last_user) {
-					$usr_adds[$last_user]++;
+					$usr_adds[$last_user] = isset($usr_adds[$last_user]) ? ($usr_adds[$last_user]+1) : 0 ;
 				}
 			}
 		}
